@@ -1,17 +1,17 @@
-import os
+
 import sys
 import datetime
+import pymongo
+
 import base64
 import hmac
 import random
 import hashlib
 
-import pymongo
-
-from alerta.app import app, severity_code, status_code
-from alerta.alert import AlertDocument
-from alerta.heartbeat import HeartbeatDocument
-
+from alerta.app import app
+from alerta.common.alert import AlertDocument
+from alerta.common.heartbeat import HeartbeatDocument
+from alerta.common import severity_code, status_code
 
 LOG = app.logger
 
@@ -26,38 +26,13 @@ class Mongo(object):
 
     def connect(self):
 
-        if 'MONGO_PORT' in os.environ and 'tcp://' in os.environ['MONGO_PORT']:  # Docker
-            host, port = os.environ['MONGO_PORT'][6:].split(':')
-            try:
-                self.conn = pymongo.MongoClient(host, int(port))
-            except Exception, e:
-                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGO_PORT'], e)
-                sys.exit(1)
-
-        elif 'MONGOHQ_URL' in os.environ:
-            try:
-                self.conn = pymongo.MongoClient(os.environ['MONGOHQ_URL'])
-            except Exception, e:
-                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGOHQ_URL'], e)
-                sys.exit(1)
-            app.config['MONGO_DATABASE'] = os.environ['MONGOHQ_URL'].split('/')[-1]
-
-        elif 'MONGOLAB_URI' in os.environ:
-            try:
-                self.conn = pymongo.MongoClient(os.environ['MONGOLAB_URI'])
-            except Exception, e:
-                LOG.error('MongoDB Client connection error - %s : %s', os.environ['MONGOLAB_URI'], e)
-                sys.exit(1)
-            app.config['MONGO_DATABASE'] = os.environ['MONGOLAB_URI'].split('/')[-1]
-
-        elif not app.config['MONGO_REPLSET']:
+        if not app.config['MONGO_REPLSET']:
             try:
                 self.conn = pymongo.MongoClient(app.config['MONGO_HOST'], app.config['MONGO_PORT'])
             except Exception, e:
                 LOG.error('MongoDB Client connection error - %s:%s : %s', app.config['MONGO_HOST'], app.config['MONGO_PORT'], e)
                 sys.exit(1)
-            LOG.debug('Connected to mongodb://%s:%s/%s', app.config['MONGO_HOST'], app.config['MONGO_PORT'], app.config['MONGO_DATABASE'])
-
+            LOG.info('Connected to mongodb://%s:%s/%s', app.config['MONGO_HOST'], app.config['MONGO_PORT'], app.config['MONGO_DATABASE'])
         else:
             try:
                 self.conn = pymongo.MongoClient(app.config['MONGO_HOST'], app.config['MONGO_PORT'], replicaSet=app.config['MONGO_REPLSET'])
@@ -65,8 +40,8 @@ class Mongo(object):
                 LOG.error('MongoDB Client ReplicaSet connection error - %s:%s (replicaSet=%s) : %s',
                           app.config['MONGO_HOST'], app.config['MONGO_PORT'], app.config['MONGO_REPLSET'], e)
                 sys.exit(1)
-            LOG.debug('Connected to mongodb://%s:%s/%s?replicaSet=%s', app.config['MONGO_HOST'],
-                      app.config['MONGO_PORT'], app.config['MONGO_DATABASE'], app.config['MONGO_REPLSET'])
+            LOG.info('Connected to mongodb://%s:%s/%s?replicaSet=%s',
+                     app.config['MONGO_HOST'], app.config['MONGO_PORT'], app.config['MONGO_DATABASE'], app.config['MONGO_REPLSET'])
 
         self.db = self.conn[app.config['MONGO_DATABASE']]
 
@@ -77,10 +52,9 @@ class Mongo(object):
                 LOG.error('MongoDB authentication failed: %s', e)
                 sys.exit(1)
 
-        LOG.debug('Available MongoDB collections: %s', ','.join(self.db.collection_names()))
+        LOG.info('Available MongoDB collections: %s', ','.join(self.db.collection_names()))
 
-        if app.config['MONGO_REPLSET']:
-            self.create_indexes()
+        self.create_indexes()
 
     def create_indexes(self):
 
@@ -149,9 +123,6 @@ class Mongo(object):
 
     def get_alerts(self, query=None, fields=None, sort=None, limit=0):
 
-        if 'status' not in query:
-            query = {"status": {'$ne': "expired"}}
-
         responses = self.db.alerts.find(query, fields=fields, sort=sort).limit(limit)
 
         alerts = list()
@@ -341,7 +312,8 @@ class Mongo(object):
                                    query=query,
                                    update=update,
                                    new=True,
-                                   fields={"history": 0})["value"]
+                                   fields={"history": 0}
+                                   )["value"]
 
         return AlertDocument(
             id=response['_id'],
@@ -414,8 +386,6 @@ class Mongo(object):
                 "status": status,
                 "value": alert.value,
                 "text": alert.text,
-                "tags": alert.tags,
-                "attributes": alert.attributes,
                 "createTime": alert.create_time,
                 "rawData": alert.raw_data,
                 "duplicateCount": 0,
@@ -455,7 +425,8 @@ class Mongo(object):
                                    query=query,
                                    update=update,
                                    new=True,
-                                   fields={"history": 0})["value"]
+                                   fields={"history": 0}
+                                   )["value"]
 
         return AlertDocument(
             id=response['_id'],
@@ -490,7 +461,7 @@ class Mongo(object):
 
         trend_indication = severity_code.trend(severity_code.UNKNOWN, alert.severity)
         if alert.status == status_code.UNKNOWN:
-            status = severity_code.status_from_severity(severity_code.UNKNOWN, alert.severity)
+                    status = severity_code.status_from_severity(severity_code.UNKNOWN, alert.severity)
         else:
             status = alert.status
 
@@ -623,9 +594,7 @@ class Mongo(object):
         """
         query = {'_id': {'$regex': '^' + id}}
 
-        event = self.db.alerts.find_one(query, fields={"event": 1, "_id": 0})
-        if not event:
-            return False
+        event = self.db.alerts.find_one(query, fields={"event": 1, "_id": 0})['event']
 
         now = datetime.datetime.utcnow()
         update = {
@@ -647,7 +616,8 @@ class Mongo(object):
                                    query=query,
                                    update=update,
                                    new=True,
-                                   fields={"history": 0})["value"]
+                                   fields={"history": 0}
+                                   )["value"]
 
         return AlertDocument(
             id=response['_id'],
@@ -684,7 +654,7 @@ class Mongo(object):
         """
         response = self.db.alerts.update({'_id': {'$regex': '^' + id}}, {'$addToSet': {"tags": {'$each': tags}}})
 
-        return response.get('updatedExisting', False)
+        return True if 'ok' in response else False
 
     def untag_alert(self, id, tags):
         """
@@ -692,33 +662,20 @@ class Mongo(object):
         """
         response = self.db.alerts.update({'_id': {'$regex': '^' + id}}, {'$pullAll': {"tags": tags}})
 
-        return response.get('updatedExisting', False)
+        return True if 'ok' in response else False
 
     def delete_alert(self, id):
 
         response = self.db.alerts.remove({'_id': {'$regex': '^' + id}})
 
-        return response.get('ok', False) and response.get('n', 0) == 1
+        return True if 'ok' in response else False
 
-    def get_counts(self, query=None, fields=None, group=None):
+    def get_counts(self, query=None):
         """
-        Return counts grouped by severity or status.
+        Return total and dict() of severity and status counts.
         """
-        fields = fields or {}
 
-        pipeline = [
-            {'$match': query},
-            {'$project': fields},
-            {'$group': {"_id": "$" + group, "count": {'$sum': 1}}}
-        ]
-
-        responses = self.db.alerts.aggregate(pipeline)
-
-        counts = dict()
-        for response in responses['result']:
-            counts[response['_id']] = response['count']
-
-        return counts
+        return self.db.alerts.find(query, {"severity": 1, "status": 1})
 
     def get_topn(self, query=None, group=None, limit=10):
 
@@ -858,52 +815,14 @@ class Mongo(object):
                                        query={"origin": heartbeat.origin},
                                        update=update,
                                        new=True,
-                                       upsert=True)["value"]
-
-            return HeartbeatDocument(
-                id=response['_id'],
-                origin=response['origin'],
-                tags=response['tags'],
-                event_type=response['type'],
-                create_time=response['createTime'],
-                timeout=response['timeout'],
-                receive_time=response['receiveTime']
-            )
+                                       upsert=True
+                                       )["value"]
+            return response['_id']
         else:
             update = update['$set']
             update["_id"] = heartbeat.id
             response = self.db.heartbeats.insert(update)
-
-            return HeartbeatDocument(
-                id=response,
-                origin=update['origin'],
-                tags=update['tags'],
-                event_type=update['type'],
-                create_time=update['createTime'],
-                timeout=update['timeout'],
-                receive_time=update['receiveTime']
-            )
-
-    def get_heartbeat(self, id):
-
-        if len(id) == 8:
-            query = {'$or': [{'_id': {'$regex': '^' + id}}, {'lastReceiveId': {'$regex': '^' + id}}]}
-        else:
-            query = {'$or': [{'_id': id}, {'lastReceiveId': id}]}
-
-        response = self.db.heartbeats.find_one(query)
-        if not response:
-            return
-
-        return HeartbeatDocument(
-            id=response['_id'],
-            tags=response['tags'],
-            origin=response['origin'],
-            event_type=response['type'],
-            create_time=response['createTime'],
-            timeout=response['timeout'],
-            receive_time=response['receiveTime']
-        )
+            return response
 
     def delete_heartbeat(self, id):
 
@@ -935,8 +854,7 @@ class Mongo(object):
     def delete_user(self, user):
 
         response = self.db.users.remove({"user": user})
-
-        return response.get('ok', False) and response.get('n', 0) == 1
+        return True if 'ok' in response else False
 
     def get_metrics(self):
 
@@ -1015,8 +933,7 @@ class Mongo(object):
     def delete_key(self, key):
 
         response = self.db.keys.remove({"key": key})
-
-        return response.get('ok', False) and response.get('n', 0) == 1
+        return True if 'ok' in response else False
 
     def is_token_valid(self, token):
 
@@ -1036,4 +953,4 @@ class Mongo(object):
         if self.conn.alive():
             self.conn.disconnect()
 
-        LOG.debug('Mongo disconnected.')
+        LOG.info('Mongo disconnected.')
